/*
 * See the NOTICE file distributed with this work for information
 * regarding copyright ownership.  This file is licensed
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.fabric3.scdl;

import java.net.URI;

import org.fabric3.scdl.validation.MissingPromotion;

/**
 * Representation of a service exposed by a composite component type.
 *
 * @version $Rev: 3727 $ $Date: 2008-04-25 09:47:42 -0700 (Fri, 25 Apr 2008) $
 */
public class CompositeService extends ServiceDefinition {
    private URI promote;

    /**
     * Create a composite service definition.
     *
     * @param name            the name to assign to the service
     * @param serviceContract the service contract to expose
     * @param promote         the component service that is being promoted
     */
    public CompositeService(String name, ServiceContract<?> serviceContract, URI promote) {
        super(name, serviceContract);
        this.promote = promote;
    }

    /**
     * Returns the URI of the component service that is being promoted.
     *
     * @return the URI of the component service that is being promoted
     */
    public URI getPromote() {
        return promote;
    }

    @Override
    public void validate(ValidationContext context) {
        super.validate(context);
        if (promote == null) {
            context.addError(new MissingPromotion(this));
        }
    }
}
